# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-09-17 11:07
from __future__ import unicode_literals

from django.db import migrations
import djangoldp.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_notification', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='notification',
            name='urlid',
            field=djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='subscription',
            name='urlid',
            field=djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True),
        ),
    ]
